Module utils

Module utils 

Utility functions for working with source positions

Functions

line_col_to_offset
Convert line and column numbers to a byte offset
offset_to_location
Convert a byte offset to a Location with line and column info
range_from_offsets
Create a Range from start and end byte offsets