pub fn range_from_offsets(start: usize, end: usize) -> RangeExpand description
Create a Range from start and end byte offsets
This is a helper that creates a Range with Location structs
that only have offsets filled in (row and column are 0).
Use offset_to_location to get full Location info.